BudgetRecipient

Trait BudgetRecipient 

pub trait BudgetRecipient<AccountId> {
    // Required methods
    fn budget_key() -> BudgetKey;
    fn pot_account() -> AccountId;
}
A recipient of inflation budget.

Pallets that want a share of inflation implement this trait, providing a unique key and a pot account where minted funds are deposited.

Required Methods

fn budget_key() -> BudgetKey

Unique identifier for this budget category.

fn pot_account() -> AccountId

The account that receives minted inflation funds.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors