Type Definition sp_staking::SessionIndex [−][src]
pub type SessionIndex = u32;Expand description
Simple index type with which we can count sessions.
pub type SessionIndex = u32;Simple index type with which we can count sessions.